#
# spec file for package uacme
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2020, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           uacme
Version:        1.2.3
Release:        lp152.1.2
Summary:        A minimal ACMEv2 client
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Other
URL:            https://github.com/ndilieto/uacme
Source:         https://github.com/ndilieto/uacme/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE suse-www-path.patch
# find . -type f -exec sed -i 's|/var/www|/srv/www/htdocs|g' {} \;
Patch1:         suse-www-path.patch
BuildRequires:  asciidoc
BuildRequires:  libev-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gnutls) >= 3.3.30
BuildRequires:  pkgconfig(libcurl) >= 7.38.0

%description
uacme is a client for the ACMEv2 protocol described in RFC8555,
written in plain C code with minimal dependencies.
The ACMEv2 protocol allows a Certificate Authority and an
applicant to automate the process of verification and certificate
issuance. The protocol also provides facilities for other
certificate management functions, such as certificate revocation.

%prep
%setup -q
%patch1 -p1

%build
%configure
make %{?_smp_mflags}

%install
%make_install
mv %{buildroot}/%{_datadir}/doc/uacme/*.html .

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS README README.md THANKS
%doc uacme.html ualpn.html
%{_bindir}/uacme
%{_bindir}/ualpn
%{_mandir}/man1/uacme.1%{?ext_man}
%{_mandir}/man1/ualpn.1%{?ext_man}
%dir %{_datadir}/uacme
%{_datadir}/uacme/uacme.sh
%{_datadir}/uacme/ualpn.sh

%changelog
* Sun Apr 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.3
  * fix Content-Type header parsing
* Sun Apr 19 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.2
  * fix ualpn socket type bug on uClibc based systems
  * fix configure.ac MAP_ANON cross-compilation test
* Fri Apr 17 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.1
  * increase cert buf size to cope with long identifiers
  * fix gcc8 -Wstringop-truncation warning
- Update to version 1.2
  * add uacme OCSP certificate status check
  * add ualpn OpenSSL/mbedTLS implementations
  * add key usage to ualpn challenge certificate
  * ensure top bit of ualpn certificate S/N is 0 with OpenSSL
  * fix ualpn memory leaks and corner case bugs
  * minor cosmetic code and documentation changes
* Fri Mar 13 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.1.2
  * fix configure.ac typo affecting LDFLAGS
- Update to version 1.1.1
  * fix typo breaking build without HAVE_SPLICE
  * fix addr_t name collision on s390x
- Update to version 1.1
  * added IP identifier support (RFC8738)
  * added tls-alpn-01 (RFC8737) challenge responder (ualpn)
- Update patch:
  * suse-www-path.patch
- With version 1.1 a new binary named "ualpn" was added.
  "ualpn" can be used as a proxying ACMEv2 tls-alpn-01 responder
- Add libev-devel to BuildRequires (needed by ualpn)
* Thu Mar  5 2020 Adrian Schröter <adrian@suse.de>
- default to /srv/www/htdocs instead of /var/www for web server path
  Add patch:
  * suse-www-path.patch
* Sun Feb  2 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.22
  * relax account status check (compatibility with buypass.no)
  * allow client challenge retry requests (RFC8555 sec. 7.1.6)
  * pass -L flag to a2x in order to avoid depending on xmllint
  * add wildcard clarification in manpage
- Update to version 1.0.21
  * Fixed uacme.sh: https://github.com/ndilieto/uacme/pull/12
  * Added LFS support (AC_SYS_LARGEFILE)
* Sat Jan  4 2020 Martin Hauke <mardnh@gmx.de>
- Initial package, version 1.0.20
